class NotesApp {
  constructor() {
    this.pages = JSON.parse(localStorage.getItem('pages')) || [];
    this.currentPage = null;
    this.init();
  }

  init() {
    this.bindElements();
    this.bindEvents();
    this.renderPagesList();
  }

  bindElements() {
    this.newPageBtn = document.getElementById('newPageBtn');
    this.pagesList = document.getElementById('pagesList');
    this.editor = document.getElementById('editor');
    this.blockType = document.getElementById('blockType');
    this.addBlockBtn = document.getElementById('addBlockBtn');
  }

  bindEvents() {
    this.newPageBtn.addEventListener('click', () => this.createNewPage());
    this.addBlockBtn.addEventListener('click', () => this.addBlock());
  }

  createNewPage() {
    const page = {
      id: Date.now(),
      title: 'Untitled Page',
      blocks: []
    };
    this.pages.push(page);
    this.savePagesToStorage();
    this.renderPagesList();
    this.setCurrentPage(page);
  }

  setCurrentPage(page) {
    this.currentPage = page;
    this.renderEditor();
  }

  addBlock() {
    if (!this.currentPage) return;
    
    const block = {
      id: Date.now(),
      type: this.blockType.value,
      content: ''
    };
    
    this.currentPage.blocks.push(block);
    this.savePagesToStorage();
    this.renderEditor();
  }

  renderPagesList() {
    this.pagesList.innerHTML = this.pages.map(page => `
      <div class="page" data-id="${page.id}">
        <span>${page.title}</span>
      </div>
    `).join('');
  }

  renderEditor() {
    if (!this.currentPage) {
      this.editor.innerHTML = '<p>Select or create a page</p>';
      return;
    }

    this.editor.innerHTML = this.currentPage.blocks.map(block => `
      <div class="block" data-id="${block.id}">
        ${this.renderBlock(block)}
      </div>
    `).join('');
  }

  renderBlock(block) {
    switch(block.type) {
      case 'text':
        return `<div contenteditable="true" class="text-block">${block.content}</div>`;
      case 'heading':
        return `<h2 contenteditable="true">${block.content}</h2>`;
      case 'list':
        return `<ul contenteditable="true">${block.content}</ul>`;
      case 'table':
        return `<div class="table-block">${block.content}</div>`;
      case 'code':
        return `<pre><code contenteditable="true">${block.content}</code></pre>`;
      default:
        return '';
    }
  }

  savePagesToStorage() {
    localStorage.setItem('pages', JSON.stringify(this.pages));
  }
}

document.addEventListener('DOMContentLoaded', () => {
  window.notesApp = new NotesApp();
});
